﻿# This file is in the public domain. Feel free to modify it as a basis
# for your own screens.

# Note that many of these screens may be given additional arguments in the
# future. The use of **kwargs in the parameter list ensures your code will
# work in the future.

##############################################################################
# Splash

label splashscreen:
    
    scene black
    with Pause(1)
    
    show splash with dissolve
    with Pause (2)
    
    scene black with dissolve
    with Pause(1)
    
    show text "{i}\"If we happened, just happened, to discover, or even suspect, that our spontaneity was part of their order, we'd know that we were lost.\" -Tom Stoppard, Rosencrantz and Guildenstern are Dead{/i}" with dissolve
    with Pause(8)
    
    scene black with dissolve
    with Pause(1)
    
    return

##############################################################################
# Say
#
# Screen that's used to display adv-mode dialogue.
# http://www.renpy.org/doc/html/screen_special.html#say
screen say(who, what, side_image=None, two_window=False):

    # Decide if we want to use the one-window or two-window variant.
    if not two_window:

        # The one window variant.
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:
                window:
                    style "say_who_window"

                    text who:
                        id "who"

            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"

    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu


##############################################################################
# Choice
#
# Screen that's used to display in-game menus.
# http://www.renpy.org/doc/html/screen_special.html#choice

screen choice(items):

    window:
        style "menu_window"
        xalign 0.5
        yalign 0.5

        vbox:
            style "menu"
            spacing 2

            for caption, action, chosen in items:

                if action:

                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"

                else:
                    text caption style "menu_caption"

init -2:
    $ config.narrator_menu = True

    style menu_window is default

    style menu_choice is button_text:
        clear

    style menu_choice_button is button:
        xminimum int(config.screen_width * 0.75)
        xmaximum int(config.screen_width * 0.75)


##############################################################################
# Input
#
# Screen that's used to display renpy.input()
# http://www.renpy.org/doc/html/screen_special.html#input

screen input(prompt):

    window style "input_window":
        has vbox

        text prompt style "input_prompt"
        input id "input" style "input_text"

    use quick_menu

##############################################################################
# Nvl
#
# Screen used for nvl-mode dialogue and menus.
# http://www.renpy.org/doc/html/screen_special.html#nvl

screen nvl(dialogue, items=None):

    window:
        style "nvl_window"

        has vbox:
            style "nvl_vbox"

        # Display dialogue.
        for who, what, who_id, what_id, window_id in dialogue:
            window:
                id window_id

                has hbox:
                    spacing 10

                if who is not None:
                    text who id who_id

                text what id what_id

        # Display a menu, if given.
        if items:

            vbox:
                id "menu"

                for caption, action, chosen in items:

                    if action:

                        button:
                            style "nvl_menu_choice_button"
                            action action

                            text caption style "nvl_menu_choice"

                    else:

                        text caption style "nvl_dialogue"

    add SideImage() xalign 0.0 yalign 1.0

    use quick_menu

##############################################################################
# Main Menu
#
# Screen that's used to display the main menu, when Ren'Py first starts
# http://www.renpy.org/doc/html/screen_special.html#main-menu

screen main_menu():

    # This ensures that any other menu screen is replaced.
    tag menu

    # The background of the main menu.
    window:
        style "mm_root"
     
    # Dynamic Menu Images
    
    if not persistent.endend == True:
        
        if persistent.escend == True:
            
            frame: 
                style_group "mm"
                background "images/Title Screen EscEnd.png"
        
        if persistent.sugend == True:
            
            frame:
                style_group "mm"
                background "images/SugEnd.png"
        
        if persistent.murdend == True:
            
            frame:
                style_group "mm"
                background "images/MurdEnd.png"
        
        if persistent.playend == True:
            
            frame:
                style_group "mm"
                background "images/PlayEnd.png"
        
        if persistent.resend == True:
            
            frame:
                style_group "mm"
                background "images/ResEnd.png"
        
        if persistent.suiend == True:
            
            frame:
                style_group "mm"
                background "images/SuiEnd.png"
        
        if persistent.godend == True:
            
            frame:
                style_group "mm"
                background "images/GodEnd.png"
        
        if persistent.broend == True:
            
            frame:
                style_group "mm"
                background "images/BroEnd.png"
        
        if persistent.impend == True:
            
            frame:
                style_group "mm"
                background "images/ImpEnd.png"
        
        if persistent.deadend == True:
            
            frame:
                style_group "mm"
                background "images/DeadEnd.png"
        
        if persistent.falseend == True:
            
            frame:
                style_group "mm"
                background "images/FalseEnd.png"
        
    else:
        
        frame:
            style_group "mm"
            background "images/EndEnd.png"
    
    # The main menu buttons.
   
    if persistent.afterword == True:
       
        frame:
            style_group "mm"
            background None
            xalign .5
            yalign .02
           
            has hbox
           
            textbutton _("[[{i}Afterword{/i}]") action ShowMenu("halfterword")
            textbutton _("[[{i}Afterword{/i}]") action ShowMenu("afterword")
        
        frame:
            style_group "mm"
            background "images/Strikethrough.png"
            top_margin 10
            left_margin 6
   
    elif persistent.halfterword == True:
       
        frame:
            style_group "mm"
            background None
            xalign .5
            yalign .02
           
            has hbox
           
            textbutton _("[[{i}Afterword{/i}]") action ShowMenu("halfterword")
    
    frame:
        style_group "mm"
        background None
        left_margin 235
        top_margin 530

        has hbox

        textbutton _("[[{i}Start Game{/i}]") action Start()
        textbutton _("[[{i}Load Game{/i}]") action ShowMenu("load")
        
    frame:
        style_group "mm"
        background None
        left_margin 115
        top_margin 560
        
        has hbox
        
        textbutton _("[[{i}Preferences{/i}]") action ShowMenu("preferences")
        textbutton _("[[{i}Help{/i}]") action Help()
        textbutton _("[[{i}Quit{/i}]") action Quit(confirm=False)

init -2:

    # Make all the main menu buttons be the same size.
    style mm_button:
        size_group "mm"



##############################################################################
# Navigation
#
# Screen that's included in other screens to display the game menu
# navigation and background.
# http://www.renpy.org/doc/html/screen_special.html#navigation
screen navigation():

    # The background of the game menu.
    window:
        style "gm_root"

    # The various buttons.
        
    frame:
        style_group "gm_nav"
        background None
        xalign .02
        ypos 530
        
        has hbox
    
        textbutton _("[[{i}Save Game{/i}]") action ShowMenu("save")
        textbutton _("[[{i}Load Game{/i}]") action ShowMenu("load")
    
    frame:
        style_group "gm_nav"
        background None
        xalign .48
        ypos 560
        
        has hbox
    
        textbutton _("[[{i}Return{/i}]") action Return()
        textbutton _("[[{i}Preferences{/i}]") action ShowMenu("preferences")
        textbutton _("[[{i}Main Menu{/i}]") action MainMenu()
    
    frame:
        style_group "gm_nav"
        background None
        xalign .91
        ypos 590
        
        has hbox
        
        textbutton _("[[{i}Help{/i}]") action Help()
        textbutton _("[[{i}Quit{/i}]") action Quit()

init -2:

    # Make all game menu navigation buttons the same size.
    style gm_nav_button:
        size_group "gm_nav"


##############################################################################
# Save, Load
#
# Screens that allow the user to save and load the game.
# http://www.renpy.org/doc/html/screen_special.html#save
# http://www.renpy.org/doc/html/screen_special.html#load

# Since saving and loading are so similar, we combine them into
# a single screen, file_picker. We then use the file_picker screen
# from simple load and save screens.

screen file_picker():

    frame:
        style "file_picker_frame"

        has vbox

        # The buttons at the top allow the user to pick a
        # page of files.
        hbox:
            style_group "file_picker_nav"

            textbutton _("Previous"):
                action FilePagePrevious()

            textbutton _("Auto"):
                action FilePage("auto")

            textbutton _("Quick"):
                action FilePage("quick")

            for i in range(1, 9):
                textbutton str(i):
                    action FilePage(i)

            textbutton _("Next"):
                action FilePageNext()

        $ columns = 2
        $ rows = 5

        # Display a grid of file slots.
        grid columns rows:
            transpose True
            xfill True
            style_group "file_picker"

            # Display ten file slots, numbered 1 - 10.
            for i in range(1, columns * rows + 1):

                # Each file slot is a button.
                button:
                    action FileAction(i)
                    xfill True

                    has hbox

                    # Add the screenshot.
                    add FileScreenshot(i)

                    $ file_name = FileSlotName(i, columns * rows)
                    $ file_time = FileTime(i, empty=_("Empty Slot."))
                    $ save_name = FileSaveName(i)

                    text "[file_name]. [file_time!t]\n[save_name!t]"

                    key "save_delete" action FileDelete(i)


screen save():

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

screen load():

    # This ensures that any other menu screen is replaced.
    tag menu

    use navigation
    use file_picker

init -2:
    style file_picker_frame is menu_frame
    style file_picker_nav_button is small_button
    style file_picker_nav_button_text is small_button_text
    style file_picker_button is large_button
    style file_picker_text is large_button_text


##############################################################################
# Preferences
#
# Screen that allows the user to change the preferences.
# http://www.renpy.org/doc/html/screen_special.html#prefereces

screen preferences():

    tag menu

    # Include the navigation.
    use navigation

    # Put the navigation columns in a three-wide grid.
    grid 3 1:
        style_group "prefs"
        xfill True

        # The left column.
        vbox:
            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Display{/i}]")
                textbutton _("[[{i}Window{/i}]") action Preference("display", "window")
                textbutton _("[[{i}Fullscreen{/i}]") action Preference("display", "fullscreen")

            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Transitions{/i}]")
                textbutton _("[[{i}All{/i}]") action Preference("transitions", "all")
                textbutton _("[[{i}None{/i}]") action Preference("transitions", "none")

            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Text Speed{/i}]")
                bar value Preference("text speed")

            frame:
                style_group "pref"
                background None
                has vbox

                textbutton _("[[{i}Joystick...{/i}]") action Preference("joystick")


        vbox:
            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Skip{/i}]")
                textbutton _("[[{i}Seen Messages{/i}]") action Preference("skip", "seen")
                textbutton _("[[{i}All Messages{/i}]") action Preference("skip", "all")

            frame:
                style_group "pref"
                background None
                has vbox

                textbutton _("[[{i}Begin Skipping{/i}]") action Skip()

            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}After Choices{/i}]")
                textbutton _("[[{i}Stop Skipping{/i}]") action Preference("after choices", "stop")
                textbutton _("[[{i}Keep Skipping{/i}]") action Preference("after choices", "skip")

            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Auto-Forward Time{/i}]")
                bar value Preference("auto-forward time")

                if config.has_voice:
                    textbutton _("[[{i}Wait for Voice{/i}]") action Preference("wait for voice", "toggle")

        vbox:
            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Music Volume{/i}]")
                bar value Preference("music volume")

            frame:
                style_group "pref"
                background None
                has vbox

                label _("[[{i}Sound Volume{/i}]")
                bar value Preference("sound volume")

                if config.sample_sound:
                    textbutton _("[[{i}Test{/i}]"):
                        action Play("sound", config.sample_sound)
                        style "soundtest_button"

            if config.has_voice:
                frame:
                    style_group "pref"
                    background None
                    has vbox

                    label _("[[{i}Voice Volume{/i}]")
                    bar value Preference("voice volume")

                    textbutton _("[[{i}Voice Sustain{/i}]") action Preference("voice sustain", "toggle")
                    if config.sample_voice:
                        textbutton _("[[{i}Test{/i}]"):
                            action Play("voice", config.sample_voice)
                            style "soundtest_button"

init -2:
    style pref_frame:
        xfill True
        xmargin 5
        top_margin 5

    style pref_vbox:
        xfill True

    style pref_button:
        size_group "pref"
        xalign 1.0

    style pref_slider:
        xmaximum 192
        xalign 1.0

    style soundtest_button:
        xalign 1.0
    
    style pref_slider:
        left_bar "#ffffff"
        right_bar "#888888"
        ymaximum 15


##############################################################################
# Yes/No Prompt
#
# Screen that asks the user a yes or no question.
# http://www.renpy.org/doc/html/screen_special.html#yesno-prompt

screen yesno_prompt(message, yes_action, no_action):

    modal True

    window:
        style "gm_root"

    frame:
        style_group "yesno"
        background None

        xfill True
        xmargin .05
        ypos .1
        yanchor 0
        ypadding .05

        has vbox:
            xalign .5
            yalign .5
            spacing 30

        label _(message):
            xalign 0.5

        hbox:
            xalign 0.5
            spacing 100

            textbutton _("[[{i}Yes{/i}]") action yes_action
            textbutton _("[[{i}No{/i}]") action no_action

    # Right-click and escape answer "no".
    key "game_menu" action no_action

init -2:
    style yesno_button:
        size_group "yesno"

    style yesno_label_text:
        text_align 0.5
        layout "subtitle"
        color "#ffffff"


##############################################################################
# Quick Menu
#
# A screen that's included by the default say screen, and adds quick access to
# several useful functions.
screen quick_menu():

    # Add an in-game quick menu.
    hbox:
        style_group "quick"

        xalign 1.0
        yalign 1.0

        textbutton _("Back") action Rollback()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Q.Save") action QuickSave()
        textbutton _("Q.Load") action QuickLoad()
        textbutton _("Skip") action Skip()
        # textbutton _("F.Skip") action Skip(fast=True, confirm=True)
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')

init -2:
    style quick_button:
        is default
        background None
        xpadding 5

    style quick_button_text:
        is default
        size 12
        idle_color "#8888"
        hover_color "#ccc"
        selected_idle_color "#cc08"
        selected_hover_color "#cc0"
        insensitive_color "#4448"
        
#############################################################################
#Halfterword Screen

screen halfterword():
    
    tag menu

    window:
        style "gm_root"
    
    frame:
        style_group "mm"
        background None
        left_margin 50
        right_margin 50
        yalign .02
    
        text "     Congratulations on reaching all six endings! You've definitely seen everything. For sure.\n     I've always liked afterwords. They give you a bit of insight into the thinking of the author of a work of literature, so I'm always disappointed when a work leaves out the afterword. They're particularly rare in games, unfortunately, and that's part of why I chose to put one here. Maybe I'll start a new trend! *Laughs*\n    Thank you to my father, David Hastings, who was my introduction to both theatre and video games. Without him, {i}Stage Directions{/i} would not exist. Thank you to Renee Devault, Anna Hastings, and Sean Grossnickle, for taking the time to play this game before release and for offering suggestions. Thank you to Laurie Plankers, for being the first teacher I had to be open to discussing video games as an art form. Thank you to Ayu Sakata for presenting at Naka-Kon 2016 about game design and introducing me to Ren'Py, the engine I used to build this game. Thank you to all of my friends and family who supported me. Most importantly, thank you to those of you playing this game! I hope you like it enough to come back for the next one!\n          -Isaiah Hastings"    
    frame:
        style_group "mm"
        background None
        yalign .98
        xalign .98
        
        has hbox:
            
            textbutton _("[[{i}Main Menu{/i}]") action ShowMenu("main_menu")

#############################################################################
#Aterword Screen

screen afterword():
    
    tag menu

    window:
        style "gm_root"
    
    frame:
        style_group "mm"
        background None
        left_margin 50
        right_margin 50
        yalign .02
    
        text "     Congratulations on having seen all of the endings, for real this time!\n     I originally wrote {i}Stage Directions{/i} a little over a year ago as a short story, stuctured like a one-act play. As I remember, I had three people read it. Two were mostly confused, and one (the one whose opinion I cared more about) loved it. I considered it a success, filed it away, and mostly forgot about it. Then, when I discovered Ren'Py last spring, I started working on a different project (one I still may make into a full game) and I remembered {i}Stage Directions{/i}. I thought that it might make a good visual novel, and I ran with the idea.\n     As I was planning out the game's endings, I just kept thinking, \"What's another way I can break the rules I've established?\" One of those ways of breaking the rules led to END becoming a true character instead of just an alert message, which gave me another set of rules to play with. The ending in which A stabs B, unintentionally following the stage directions, is the ending closest to the original short story.\n     Thank you again for playing {i}Stage Directions{/i}! I hope you enjoyed playing it as much as I enjoyed making it. Until next time!\n            -Isaiah Hastings"
    
    frame:
        style_group "mm"
        background None
        yalign .98
        xalign .98
        
        has hbox:
            
            textbutton _("[[{i}Main Menu{/i}]") action ShowMenu("main_menu")

